@@ -17,6 +17,7 @@
 """ Super class for optical products """
 import logging
 from abc import abstractmethod
+from datetime import datetime
 from enum import unique
 from pathlib import Path
 from typing import Union
@@ -24,29 +25,28 @@ from typing import Union
 import geopandas as gpd
 import numpy as np
 import rasterio
-from cloudpathlib import CloudPath
+import xarray as xr
+from cloudpathlib import AnyPath, CloudPath
 from rasterio import crs as riocrs
 from rasterio.enums import Resampling
 from sertit import files, rasters
 from sertit.misc import ListEnum
-from sertit.rasters import XDS_TYPE
 
-from eoreader import cache, cached_property, utils
-from eoreader.bands import BandNames
-from eoreader.bands import OpticalBandNames as obn
+from eoreader import cache, utils
+from eoreader.bands import BandNames, SpectralBandMap
+from eoreader.bands import SpectralBandNames as spb
 from eoreader.bands import (
-    OpticalBands,
-    index,
+    indices,
     is_clouds,
     is_dem,
     is_index,
-    is_optical_band,
     is_sar_band,
+    is_spectral_band,
     to_str,
 )
 from eoreader.exceptions import InvalidBandError, InvalidIndexError
-from eoreader.keywords import CLEAN_OPTICAL
-from eoreader.products.product import Product, SensorType
+from eoreader.keywords import CLEAN_OPTICAL, TO_REFLECTANCE
+from eoreader.products.product import OrbitDirection, Product, SensorType
 from eoreader.utils import EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -80,17 +80,30 @@ DEF_CLEAN_METHOD = CleanMethod.NODATA
 class OpticalProduct(Product):
     """Super class for optical products"""
 
-    def _pre_init(self) -> None:
+    def __init__(
+        self,
+        product_path: Union[str, CloudPath, Path],
+        archive_path: Union[str, CloudPath, Path] = None,
+        output_path: Union[str, CloudPath, Path] = None,
+        remove_tmp: bool = False,
+        **kwargs,
+    ) -> None:
+        self._has_cloud_cover = False
+
+        # Initialization from the super class
+        super().__init__(product_path, archive_path, output_path, remove_tmp, **kwargs)
+
+    def _pre_init(self, **kwargs) -> None:
         """
         Function used to pre_init the products
         (setting needs_extraction and so on)
         """
         # They may be overloaded
-        if not self.band_names:
-            self.band_names = OpticalBands()
+        if not self.bands:
+            self.bands = SpectralBandMap()
         self.sensor_type = SensorType.OPTICAL
 
-    def _post_init(self) -> None:
+    def _post_init(self, **kwargs) -> None:
         """
         Function used to post_init the products
         (setting sensor type, band names and so on)
@@ -107,12 +120,12 @@ class OpticalProduct(Product):
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
             >>> prod.get_default_band()
-            <OpticalBandNames.GREEN: 'GREEN'>
+            <SpectralBandNames.GREEN: 'GREEN'>
 
         Returns:
             str: Default band
         """
-        return obn.GREEN
+        return spb.GREEN
 
     def get_default_band_path(self, **kwargs) -> Union[CloudPath, Path]:
         """
@@ -134,7 +147,7 @@ class OpticalProduct(Product):
         default_band = self.get_default_band()
         return self.get_band_paths([default_band], **kwargs)[default_band]
 
-    @cached_property
+    @cache
     def crs(self) -> riocrs.CRS:
         """
         Get UTM projection of the tile
@@ -144,7 +157,7 @@ class OpticalProduct(Product):
             >>> from eoreader.reader import Reader
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
-            >>> prod.crs
+            >>> prod.crs()
             CRS.from_epsg(32630)
 
         Returns:
@@ -156,7 +169,7 @@ class OpticalProduct(Product):
 
         return utm
 
-    @cached_property
+    @cache
     def extent(self) -> gpd.GeoDataFrame:
         """
         Get UTM extent of the tile
@@ -166,19 +179,19 @@ class OpticalProduct(Product):
             >>> from eoreader.reader import Reader
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
-            >>> prod.extent
+            >>> prod.extent()
                                                         geometry
             0  POLYGON ((309780.000 4390200.000, 309780.000 4...
 
         Returns:
-            gpd.GeoDataFrame: Footprint in UTM
+            gpd.GeoDataFrame: Extent in UTM
         """
         # Get extent
-        return rasters.get_extent(self.get_default_band_path()).to_crs(self.crs)
+        return rasters.get_extent(self.get_default_band_path()).to_crs(self.crs())
 
     def get_existing_bands(self) -> list:
         """
-        Return the existing band paths.
+        Return the existing band.
 
         .. code-block:: python
 
@@ -186,28 +199,28 @@ class OpticalProduct(Product):
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
             >>> prod.get_existing_bands()
-            [<OpticalBandNames.CA: 'COASTAL_AEROSOL'>,
-            <OpticalBandNames.BLUE: 'BLUE'>,
-            <OpticalBandNames.GREEN: 'GREEN'>,
-            <OpticalBandNames.RED: 'RED'>,
-            <OpticalBandNames.VRE_1: 'VEGETATION_RED_EDGE_1'>,
-            <OpticalBandNames.VRE_2: 'VEGETATION_RED_EDGE_2'>,
-            <OpticalBandNames.VRE_3: 'VEGETATION_RED_EDGE_3'>,
-            <OpticalBandNames.NIR: 'NIR'>,
-            <OpticalBandNames.NNIR: 'NARROW_NIR'>,
-            <OpticalBandNames.WV: 'WATER_VAPOUR'>,
-            <OpticalBandNames.CIRRUS: 'CIRRUS'>,
-            <OpticalBandNames.SWIR_1: 'SWIR_1'>,
-            <OpticalBandNames.SWIR_2: 'SWIR_2'>]
+            [<SpectralBandNames.CA: 'COASTAL_AEROSOL'>,
+            <SpectralBandNames.BLUE: 'BLUE'>,
+            <SpectralBandNames.GREEN: 'GREEN'>,
+            <SpectralBandNames.RED: 'RED'>,
+            <SpectralBandNames.VRE_1: 'VEGETATION_RED_EDGE_1'>,
+            <SpectralBandNames.VRE_2: 'VEGETATION_RED_EDGE_2'>,
+            <SpectralBandNames.VRE_3: 'VEGETATION_RED_EDGE_3'>,
+            <SpectralBandNames.NIR: 'NIR'>,
+            <SpectralBandNames.NNIR: 'NARROW_NIR'>,
+            <SpectralBandNames.WV: 'WATER_VAPOUR'>,
+            <SpectralBandNames.CIRRUS: 'CIRRUS'>,
+            <SpectralBandNames.SWIR_1: 'SWIR_1'>,
+            <SpectralBandNames.SWIR_2: 'SWIR_2'>]
 
         Returns:
             list: List of existing bands in the products
         """
-        return [name for name, nb in self.band_names.items() if nb]
+        return [name for name, nb in self.bands.items() if nb]
 
     def get_existing_band_paths(self) -> dict:
         """
-        Return the existing band paths.
+        Return the existing band paths (orthorectified if needed).
 
         .. code-block:: python
 
@@ -216,9 +229,9 @@ class OpticalProduct(Product):
             >>> prod = Reader().open(path)
             >>> prod.get_existing_band_paths()
             {
-                <OpticalBandNames.CA: 'COASTAL_AEROSOL'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B01.jp2',
+                <SpectralBandNames.CA: 'COASTAL_AEROSOL'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B01.jp2',
                 ...,
-                <OpticalBandNames.SWIR_2: 'SWIR_2'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B12.jp2'
+                <SpectralBandNames.SWIR_2: 'SWIR_2'>: 'zip+file://S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip!/S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE/GRANULE/L1C_T30TTK_A027018_20200824T111345/IMG_DATA/T30TTK_20200824T110631_B12.jp2'
             }
 
         Returns:
@@ -227,6 +240,27 @@ class OpticalProduct(Product):
         existing_bands = self.get_existing_bands()
         return self.get_band_paths(band_list=existing_bands)
 
+    def _to_reflectance(
+        self,
+        band_arr: xr.DataArray,
+        path: Union[Path, CloudPath],
+        band: BandNames,
+        **kwargs,
+    ) -> xr.DataArray:
+        """
+        Converts band to reflectance
+
+        Args:
+            band_arr (xr.DataArray): Band array to convert
+            path (Union[CloudPath, Path]): Band path
+            band (BandNames): Band to read
+            **kwargs: Other keywords
+
+        Returns:
+            xr.DataArray: Band in reflectance
+        """
+        raise NotImplementedError
+
     def _open_bands(
         self,
         band_paths: dict,
@@ -255,14 +289,20 @@ class OpticalProduct(Product):
             band_arr = self._read_band(
                 band_path, band=band, resolution=resolution, size=size, **kwargs
             )
-            # Write on disk in order not to reprocess band everytime
-            # (invalid pix management can be time consuming)
-            if (
-                not str(band_path).endswith(f"{CleanMethod.RAW.value}.tif")
-                and not str(band_path).endswith(f"{CleanMethod.CLEAN.value}.tif")
-                and not str(band_path).endswith(f"{CleanMethod.NODATA.value}.tif")
-            ):
-                # Manage invalid pixels
+
+            if not resolution:
+                resolution = band_arr.rio.resolution()[0]
+            clean_band_path = self._get_clean_band_path(
+                band, resolution=resolution, writable=True, **kwargs
+            )
+            # If raw data, clean it !
+            if AnyPath(band_path).name != clean_band_path.name:
+                # Manage reflectance
+                if kwargs.get(TO_REFLECTANCE, True):
+                    LOGGER.debug(f"Converting {band.name} to reflectance")
+                    band_arr = self._to_reflectance(band_arr, band_path, band)
+
+                # Clean pixels
                 cleaning_method = CleanMethod.from_value(
                     kwargs.get(CLEAN_OPTICAL, DEF_CLEAN_METHOD)
                 )
@@ -276,20 +316,16 @@ class OpticalProduct(Product):
                     band_arr = self._manage_invalid_pixels(
                         band_arr, band=band, **kwargs
                     )
+                band_arr.attrs["cleaning_method"] = cleaning_method.value
 
                 # Write on disk
                 try:
-                    if not resolution:
-                        resolution = band_arr.rio.resolution()[0]
-                    clean_band_path = self._get_clean_band_path(
-                        band, resolution=resolution, writable=True, **kwargs
-                    )
                     utils.write(
                         band_arr.rename(f"{to_str(band)[0]} CLEAN"), clean_band_path
                     )
                 except Exception:
                     # Not important if we cannot write it
-                    pass
+                    LOGGER.debug(f"Cannot write {clean_band_path} on disk.")
 
             # Save band array
             band_arrays[band] = band_arr
@@ -297,48 +333,76 @@ class OpticalProduct(Product):
         return band_arrays
 
     @abstractmethod
-    def _manage_invalid_pixels(
-        self, band_arr: XDS_TYPE, band: obn, **kwargs
-    ) -> XDS_TYPE:
+    def _read_band(
+        self,
+        path: Union[CloudPath, Path],
+        band: BandNames = None,
+        resolution: Union[tuple, list, float] = None,
+        size: Union[list, tuple] = None,
+        **kwargs,
+    ) -> xr.DataArray:
         """
-        Manage invalid pixels (Nodata, saturated, defective...)
+        Read band from disk.
+
+        .. WARNING::
+            Invalid pixels are not managed here
 
         Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
+            path (Union[CloudPath, Path]): Band path
+            band (BandNames): Band to read
+            resolution (Union[tuple, list, float]): Resolution of the wanted band, in dataset resolution unit (X, Y)
+            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
             kwargs: Other arguments used to load bands
-
         Returns:
-            XDS_TYPE: Cleaned band array
+            xr.DataArray: Band xarray
         """
         raise NotImplementedError
 
     @abstractmethod
-    def _manage_nodata(self, band_arr: XDS_TYPE, band: obn, **kwargs) -> XDS_TYPE:
+    def _manage_invalid_pixels(
+        self, band_arr: xr.DataArray, band: BandNames, **kwargs
+    ) -> xr.DataArray:
+        """
+        Manage invalid pixels (Nodata, saturated, defective...)
+
+        Args:
+            band_arr (xr.DataArray): Band array
+            band (BandNames): Band name as an SpectralBandNames
+            kwargs: Other arguments used to load bands
+
+        Returns:
+            xr.DataArray: Cleaned band array
+        """
+        raise NotImplementedError
+
+    @abstractmethod
+    def _manage_nodata(
+        self, band_arr: xr.DataArray, band: BandNames, **kwargs
+    ) -> xr.DataArray:
         """
         Manage only nodata pixels
 
         Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
+            band_arr (xr.DataArray): Band array
+            band (BandNames): Band name as an SpectralBandNames
             kwargs: Other arguments used to load bands
 
         Returns:
-            XDS_TYPE: Cleaned band array
+            xr.DataArray: Cleaned band array
         """
         raise NotImplementedError
 
     @staticmethod
-    def _set_nodata_mask(band_arr: XDS_TYPE, mask: np.ndarray) -> XDS_TYPE:
+    def _set_nodata_mask(band_arr: xr.DataArray, mask: np.ndarray) -> xr.DataArray:
         """
         Create the correct xarray with well positioned nodata
 
         Args:
-            band_arr (XDS_TYPE): Band array
+            band_arr (xr.DataArray): Band array
             mask (np.ndarray): Mask array
 
         Returns:
-            (XDS_TYPE): Corrected band array
+            (xr.DataArray): Corrected band array
         """
         # Binary mask
         if mask.dtype != np.uint8:
@@ -387,7 +451,7 @@ class OpticalProduct(Product):
                 raise TypeError(
                     f"You should ask for Optical bands as {self.name} is an optical product."
                 )
-            elif is_optical_band(idx_or_band):
+            elif is_spectral_band(idx_or_band):
                 if self.has_band(idx_or_band):
                     band_list.append(idx_or_band)
                 else:
@@ -406,7 +470,7 @@ class OpticalProduct(Product):
         # Get all bands to be open
         bands_to_load = band_list.copy()
         for idx in index_list:
-            bands_to_load += index.NEEDED_BANDS[idx]
+            bands_to_load += indices.NEEDED_BANDS[idx]
 
         # Load band arrays (only keep unique bands: open them only one time !)
         unique_bands = list(set(bands_to_load))
@@ -418,7 +482,7 @@ class OpticalProduct(Product):
 
         # Compute index (they conserve the nodata)
         if index_list:
-            LOGGER.debug(f"Loading index {to_str(index_list)}")
+            LOGGER.debug(f"Loading indices {to_str(index_list)}")
         bands_dict = {idx: idx(bands) for idx in index_list}
 
         # Add bands
@@ -459,6 +523,23 @@ class OpticalProduct(Product):
         """
         raise NotImplementedError
 
+    @cache
+    def get_mean_viewing_angles(self) -> (float, float, float):
+        """
+        Get Mean Viewing angles (azimuth, off-nadir and incidence angles)
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_mean_viewing_angles()
+
+        Returns:
+            (float, float, float): Mean azimuth, off-nadir and incidence angles
+        """
+        return None, None, None
+
     def _compute_hillshade(
         self,
         dem_path: str = "",
@@ -576,18 +657,18 @@ class OpticalProduct(Product):
         return band_dict
 
     def _create_mask(
-        self, xds: XDS_TYPE, cond: np.ndarray, nodata: np.ndarray
-    ) -> XDS_TYPE:
+        self, xds: xr.DataArray, cond: np.ndarray, nodata: np.ndarray
+    ) -> xr.DataArray:
         """
         Create a mask from a conditional array and a nodata mask.
 
         Args:
-            xds (XDS_TYPE): xarray to retrieve attributes
+            xds (xr.DataArray): xarray to retrieve attributes
             cond (np.ndarray): Conditional array
             nodata (np.ndarray): Nodata mask
 
         Returns:
-            XDS_TYPE: Mask as xarray
+            xr.DataArray: Mask as xarray
         """
         mask = xds.copy(data=np.where(cond, self._mask_true, self._mask_false))
         mask = mask.where(nodata == 0)
@@ -595,7 +676,11 @@ class OpticalProduct(Product):
         return mask
 
     def _get_clean_band_path(
-        self, band: obn, resolution: float = None, writable: bool = False, **kwargs
+        self,
+        band: BandNames,
+        resolution: float = None,
+        writable: bool = False,
+        **kwargs,
     ) -> Union[CloudPath, Path]:
         """
         Get clean band path.
@@ -603,7 +688,7 @@ class OpticalProduct(Product):
         The clean band is the opened band where invalid pixels have been managed.
 
         Args:
-            band (OpticalBandNames): Wanted band
+            band (BandNames): Wanted band
             resolution (float): Band resolution in meters
             writable (bool): True if we want the band folder to be writeable
             kwargs: Additional arguments
@@ -617,13 +702,16 @@ class OpticalProduct(Product):
 
         res_str = self._resolution_to_str(resolution)
 
+        # Radiometric processing
+        rad_proc = "" if kwargs.get(TO_REFLECTANCE, True) else "_as_is"
+
         return self._get_band_folder(writable).joinpath(
-            f"{self.condensed_name}_{band.name}_{res_str.replace('.', '-')}_{cleaning_method.value}.tif",
+            f"{self.condensed_name}_{band.name}_{res_str.replace('.', '-')}_{cleaning_method.value}{rad_proc}.tif",
         )
 
     def _get_cloud_band_path(
         self,
-        band: obn,
+        band: BandNames,
         resolution: float = None,
         size: Union[list, tuple] = None,
         writable: bool = False,
@@ -633,7 +721,7 @@ class OpticalProduct(Product):
         Get cloud band path.
 
         Args:
-            band (OpticalBandNames): Wanted band
+            band (BandNames): Wanted band
             resolution (float): Band resolution in meters
             writable (bool): True if we want the band folder to be writeable
             kwargs: Additional arguments
@@ -654,3 +742,111 @@ class OpticalProduct(Product):
         return self._get_band_folder(writable).joinpath(
             f"{self.condensed_name}_{band.name}_{res_str.replace('.', '-')}.tif",
         )
+
+    @cache
+    def _sun_earth_distance_variation(self) -> float:
+        """
+        Correction for the Sun-Earth distance variation
+
+        It utilises the inverse square law of irradiance, under which,
+        the intensity (or irradiance) of light radiating from a point source is inversely proportional to the square of the distance from the source.
+
+         - t is the Julian Day corresponding to the acquisition date (reference day: 01/01/1950).
+         - 0.01673 is the Earth orbit eccentricity.
+         - 0.0172 is the Earth angular velocity (radians/day).
+
+        See `here <https://sentinel.esa.int/web/sentinel/technical-guides/sentinel-2-msi/level-1c/algorithm>`_ for more information.
+
+        Returns:
+            float: Sun-Earth distance variation
+        """
+        # julian_date is the Julian Day corresponding to the acquisition date (reference day: 01/01/1950).
+        ref_julian_date = datetime(year=1950, month=1, day=1)
+        julian_date = (self.date - ref_julian_date).days + 1
+
+        # Compute Sun-Earth distance variation
+        return 1 / (1 - 0.01673 * np.cos(0.0172 * (julian_date - 2))) ** 2
+
+    @cache
+    def get_cloud_cover(self) -> float:
+        """
+        Get cloud cover as given in the metadata
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_cloud_cover()
+            55.5
+
+        Returns:
+            float: Cloud cover as given in the metadata
+        """
+        LOGGER.warning(
+            f"No cloud cover available for {self.constellation.value} data !"
+        )
+        return 0.0
+
+    def _update_attrs_constellation_specific(
+        self, xarr: xr.DataArray, bands: list, **kwargs
+    ) -> xr.DataArray:
+        """
+        Update attributes of the given array (constellation specific)
+
+        Args:
+            xarr (xr.DataArray): Array whose attributes need an update
+            bands (list): Array name (as a str or a list)
+        Returns:
+            xr.DataArray: Updated array
+        """
+        has_spectral_bands = [is_spectral_band(band) for band in bands]
+
+        # Do not add this if one non-spectral bands exists
+        if all(has_spectral_bands):
+            if kwargs.get(TO_REFLECTANCE, True):
+                xarr.attrs["radiometry"] = "reflectance"
+            else:
+                xarr.attrs["radiometry"] = "as is"
+
+        # Add this if at least one spectral bands exists
+        if any(has_spectral_bands):
+            if self._has_cloud_cover:
+                xarr.attrs["cloud_cover"] = self.get_cloud_cover()
+
+        return xarr
+
+    @cache
+    def get_orbit_direction(self) -> OrbitDirection:
+        """
+        Get cloud cover as given in the metadata
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_orbit_direction().value
+            "DESCENDING"
+
+        Returns:
+            OrbitDirection: Orbit direction (ASCENDING/DESCENDING)
+        """
+        # All optical satellite are descending by default
+        return OrbitDirection.DESCENDING
+
+    def _to_repr_constellation_specific(self) -> list:
+        """
+        Representation specific to the constellation
+
+        Returns:
+            list: Representation list (constellation specific)
+        """
+        repr = []
+        if self._has_cloud_cover:
+            repr.append(f"\tcloud cover: {self.get_cloud_cover()}")
+
+        if self.tile_name is not None:
+            repr.append(f"\ttile name: {self.tile_name}")
+
+        return repr
