@@ -16,8 +16,9 @@
 # limitations under the License.
 """
 PlanetScope products.
-See `here <https://earth.esa.int/eogateway/documents/20142/37627/Planet-combined-imagery-product-specs-2020.pdf>`_
-and `here <https://developers.planet.com/docs/data/planetscope/>`_
+See
+`Earth Online <https://assets.planet.com/docs/Planet_Combined_Imagery_Product_Specs_letter_screen.pdf>`_
+and `Planet documentation <https://developers.planet.com/docs/data/planetscope/>`_
 for more information.
 """
 import logging
@@ -26,22 +27,18 @@ from enum import unique
 from pathlib import Path
 from typing import Union
 
-import geopandas as gpd
-import numpy as np
-import xarray
+import xarray as xr
 from cloudpathlib import CloudPath
 from lxml import etree
-from rasterio.enums import Resampling
-from sertit import files, rasters
 from sertit.misc import ListEnum
-from sertit.rasters import XDS_TYPE
 
-from eoreader import cache, cached_property, utils
-from eoreader.bands import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS, BandNames
-from eoreader.bands import OpticalBandNames as obn
-from eoreader.bands import to_str
-from eoreader.exceptions import InvalidProductError, InvalidTypeError
-from eoreader.products import OpticalProduct
+from eoreader import cache
+from eoreader.bands import BandNames, SpectralBand
+from eoreader.bands import spectral_bands as spb
+from eoreader.exceptions import InvalidProductError
+from eoreader.products.optical.planet_product import PlanetProduct
+from eoreader.products.product import OrbitDirection
+from eoreader.stac import GSD, ID, NAME, WV_MAX, WV_MIN
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -175,40 +172,32 @@ class PlaProductType(ListEnum):
     """
 
 
-class PlaProduct(OpticalProduct):
+class PlaProduct(PlanetProduct):
     """
     Class of PlanetScope products.
-    See `here <https://earth.esa.int/eogateway/documents/20142/37627/Planet-combined-imagery-product-specs-2020.pdf>`__
+    See `here <https://assets.planet.com/docs/Planet_Combined_Imagery_Product_Specs_letter_screen.pdf>`__
     for more information.
 
     The scaling factor to retrieve the calibrated radiance is 0.01.
     """
 
-    def _pre_init(self) -> None:
-        """
-        Function used to pre_init the products
-        (setting needs_extraction and so on)
-        """
-        self.needs_extraction = False
-
-        # Post init done by the super class
-        super()._pre_init()
-
-    def _post_init(self) -> None:
+    def _post_init(self, **kwargs) -> None:
         """
         Function used to post_init the products
         (setting sensor type, band names and so on)
         """
+        self._has_cloud_cover = True
+
         # Ortho Tiles
         if self.product_type == PlaProductType.L3A:
             self.tile_name = self.split_name[1]
 
         # Post init done by the super class
-        super()._post_init()
+        super()._post_init(**kwargs)
 
-    def _set_resolution(self) -> float:
+    def _get_resolution(self) -> float:
         """
-        Set product default resolution (in meters)
+        Get product default resolution (in meters)
         """
         # Ortho Tiles
         if self.product_type == PlaProductType.L3A:
@@ -217,6 +206,171 @@ class PlaProduct(OpticalProduct):
         else:
             return 3.0
 
+    def _set_instrument(self) -> None:
+        """
+        Set instrument
+        """
+        # Get MTD XML file
+        root, nsmap = self.read_mtd()
+
+        # Manage constellation
+        instr_node = root.find(f".//{nsmap['eop']}Instrument")
+        instrument = instr_node.findtext(f"{nsmap['eop']}shortName")
+
+        if not instrument:
+            raise InvalidProductError("Cannot find the Instrument in the metadata file")
+
+        # Set correct constellation
+        self.instrument = getattr(PlaInstrument, instrument.replace(".", "_"))
+
+    def _get_spectral_bands(self) -> dict:
+        """
+        See <here `https://assets.planet.com/docs/Planet_Combined_Imagery_Product_Specs_letter_screen.pdf`_> for more information.
+
+        Returns:
+            dict: PlanetScope spectral bands
+        """
+        gsd = 3.7
+
+        blue = SpectralBand(
+            eoreader_name=spb.BLUE,
+            **{NAME: "Blue", ID: 2, GSD: gsd, WV_MIN: 465, WV_MAX: 515},
+        )
+
+        green = SpectralBand(
+            eoreader_name=spb.GREEN,
+            **{NAME: "Green", ID: 4, GSD: gsd, WV_MIN: 547, WV_MAX: 583},
+        )
+
+        red = SpectralBand(
+            eoreader_name=spb.RED,
+            **{NAME: "Red", ID: 6, GSD: gsd, WV_MIN: 650, WV_MAX: 680},
+        )
+
+        nir = SpectralBand(
+            eoreader_name=spb.NIR,
+            **{NAME: "NIR", ID: 8, GSD: gsd, WV_MIN: 845, WV_MAX: 885},
+        )
+
+        # Create spectral bands
+        if self.instrument == PlaInstrument.PSB_SD:
+            spectral_bands = {
+                "ca": SpectralBand(
+                    eoreader_name=spb.CA,
+                    **{NAME: "Coastal Blue", ID: 1, GSD: gsd, WV_MIN: 431, WV_MAX: 452},
+                ),
+                "blue": blue,
+                "green1": SpectralBand(
+                    eoreader_name=spb.GREEN,
+                    **{NAME: "Green I", ID: 3, GSD: gsd, WV_MIN: 513, WV_MAX: 549},
+                ),
+                "green": green.update(name="Green II"),
+                "yellow": SpectralBand(
+                    eoreader_name=spb.YELLOW,
+                    **{NAME: "Yellow", ID: 5, GSD: gsd, WV_MIN: 600, WV_MAX: 620},
+                ),
+                "red": red,
+                "vre": SpectralBand(
+                    eoreader_name=spb.VRE_1,
+                    **{NAME: "Red-Edge", ID: 7, GSD: gsd, WV_MIN: 697, WV_MAX: 713},
+                ),
+                "nir": nir,
+            }
+        elif self.instrument == PlaInstrument.PS2_SD:
+            spectral_bands = {
+                "blue": blue.update(**{ID: 1, WV_MIN: 464, WV_MAX: 517}),
+                "green": green.update(**{ID: 2, WV_MIN: 547, WV_MAX: 585}),
+                "red": red.update(**{ID: 3, WV_MIN: 650, WV_MAX: 682}),
+                "nir": nir.update(**{ID: 4, WV_MIN: 846, WV_MAX: 888}),
+            }
+        elif self.instrument == PlaInstrument.PS2:
+            spectral_bands = {
+                "blue": blue.update(**{ID: 1, WV_MIN: 455, WV_MAX: 515}),
+                "green": green.update(**{ID: 2, WV_MIN: 500, WV_MAX: 590}),
+                "red": red.update(**{ID: 3, WV_MIN: 590, WV_MAX: 670}),
+                "nir": nir.update(**{ID: 4, WV_MIN: 780, WV_MAX: 860}),
+            }
+        else:
+            raise InvalidProductError(
+                f"Non recognized PlanetScope Instrument: {self.instrument}"
+            )
+
+        return spectral_bands
+
+    def _get_band_map(self, nof_bands, **kwargs) -> dict:
+        """
+        Get band map
+        """
+        # Open spectral bands
+        ca = kwargs.get("ca")
+        blue = kwargs.get("blue")
+        green = kwargs.get("green")
+        green1 = kwargs.get("green1")
+        red = kwargs.get("red")
+        nir = kwargs.get("nir")
+        vre = kwargs.get("vre")
+        yellow = kwargs.get("yellow")
+
+        if nof_bands == 3:
+            band_map = {
+                spb.BLUE: blue.update(id=1),
+                spb.GREEN: green.update(id=2),
+                spb.RED: red.update(id=3),
+            }
+        elif nof_bands == 4:
+            band_map = {
+                spb.BLUE: blue.update(id=1),
+                spb.GREEN: green.update(id=2),
+                spb.RED: red.update(id=3),
+                spb.NIR: nir.update(id=4),
+                spb.NARROW_NIR: nir.update(id=4),
+            }
+        elif nof_bands == 5:
+            band_map = {
+                spb.BLUE: blue.update(id=1),
+                spb.GREEN: green.update(id=2),
+                spb.RED: red.update(id=3),
+                spb.VRE_1: vre.update(id=4),
+                spb.VRE_2: vre.update(id=4),
+                spb.VRE_3: vre.update(id=4),
+                spb.NIR: nir.update(id=5),
+                spb.NARROW_NIR: nir.update(id=5),
+            }
+        elif nof_bands == 8:
+            band_map = {
+                spb.CA: ca,
+                spb.BLUE: blue,
+                spb.GREEN1: green1,
+                spb.GREEN: green,
+                spb.RED: red,
+                spb.YELLOW: yellow,
+                spb.VRE_1: vre,
+                spb.NIR: nir,
+                spb.NARROW_NIR: nir,
+            }
+        else:
+            raise InvalidProductError(
+                f"Unusual number of bands ({nof_bands}) for {self.path}. "
+                f"Please check the validity of your product"
+            )
+
+        return band_map
+
+    def _map_bands(self):
+        """
+        Map bands
+        """
+        # Get MTD XML file
+        root, nsmap = self.read_mtd()
+
+        # Manage bands of the product
+        nof_bands = int(root.findtext(f".//{nsmap['ps']}numBands"))
+
+        # Set the band map
+        self.bands.map_bands(
+            self._get_band_map(nof_bands, **self._get_spectral_bands())
+        )
+
     def _set_product_type(self) -> None:
         """Set products type"""
         # Get MTD XML file
@@ -241,81 +395,6 @@ class PlaProduct(OpticalProduct):
                 f"Use it at your own risk !"
             )
 
-        # Manage platform
-        instr_node = root.find(f".//{nsmap['eop']}Instrument")
-        instrument = instr_node.findtext(f"{nsmap['eop']}shortName")
-
-        if not instrument:
-            raise InvalidProductError("Cannot find the platform in the metadata file")
-
-        # Set correct platform
-        self.instrument = getattr(PlaInstrument, instrument.replace(".", "_"))
-
-        # Manage bands of the product
-        nof_bands = len(
-            [band for band in root.iterfind(f".//{nsmap['ps']}bandSpecificMetadata")]
-        )
-        if nof_bands == 3:
-            self.band_names.map_bands({obn.BLUE: 1, obn.GREEN: 2, obn.RED: 3})
-        elif nof_bands == 4:
-            self.band_names.map_bands(
-                {obn.BLUE: 1, obn.GREEN: 2, obn.RED: 3, obn.NIR: 4, obn.NARROW_NIR: 4}
-            )
-        elif nof_bands == 5:
-            self.band_names.map_bands(
-                {
-                    obn.BLUE: 1,
-                    obn.GREEN: 2,
-                    obn.RED: 3,
-                    obn.VRE_1: 4,
-                    obn.NIR: 5,
-                    obn.NARROW_NIR: 5,
-                }
-            )
-        elif nof_bands == 8:
-            raise NotImplementedError(
-                f"8 Band Scenes are not yet implemented in EOReader: {self.path}"
-            )
-        else:
-            raise InvalidProductError(
-                f"Unusual number of bands ({nof_bands}) for {self.path}. "
-                f"Please check the validity of your product"
-            )
-
-    @cached_property
-    def footprint(self) -> gpd.GeoDataFrame:
-        """
-        Get real footprint of the products (without nodata, in french == emprise utile)
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
-            >>> prod = Reader().open(path)
-            >>> prod.footprint
-               index                                           geometry
-            0      0  POLYGON ((366165.000 4899735.000, 366165.000 4...
-
-        Overload of the generic function because landsat nodata seems to be different in QA than in regular bands.
-        Indeed, nodata pixels vary according to the band sensor footprint,
-        whereas QA nodata is where at least one band has nodata.
-
-        We chose to keep QA nodata values for the footprint in order to show where all bands are valid.
-
-        **TL;DR: We use the QA nodata value to determine the product's footprint**.
-
-        Returns:
-            gpd.GeoDataFrame: Footprint as a GeoDataFrame
-        """
-        nodata = self._load_nodata()
-
-        # Vectorize the nodata band (rasters_rio is faster)
-        footprint = rasters.vectorize(
-            nodata, values=1, keep_values=False, dissolve=True
-        ).convex_hull
-
-        return gpd.GeoDataFrame(geometry=footprint.geometry, crs=footprint.crs)
-
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
         Get the product's acquisition datetime, with format :code:`YYYYMMDDTHHMMSS` <-> :code:`%Y%m%dT%H%M%S`
@@ -360,7 +439,7 @@ class PlaProduct(OpticalProduct):
 
         return datetime_str
 
-    def _get_name(self) -> str:
+    def _get_name_constellation_specific(self) -> str:
         """
         Set product real name from metadata
 
@@ -393,9 +472,9 @@ class PlaProduct(OpticalProduct):
             >>> prod = Reader().open(path)
             >>> prod.get_band_paths([GREEN, RED])
             {
-                <OpticalBandNames.GREEN: 'GREEN'>:
+                <SpectralBandNames.GREEN: 'GREEN'>:
                 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2/SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B3.tif',
-                <OpticalBandNames.RED: 'RED'>:
+                <SpectralBandNames.RED: 'RED'>:
                 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2/SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B4.tif'
             }
 
@@ -415,150 +494,47 @@ class PlaProduct(OpticalProduct):
 
         return band_paths
 
-    def _read_band(
+    def _to_reflectance(
         self,
-        path: Union[CloudPath, Path],
-        band: BandNames = None,
-        resolution: Union[tuple, list, float] = None,
-        size: Union[list, tuple] = None,
+        band_arr: xr.DataArray,
+        path: Union[Path, CloudPath],
+        band: BandNames,
         **kwargs,
-    ) -> XDS_TYPE:
+    ) -> xr.DataArray:
         """
-        Read band from disk.
-
-        .. WARNING::
-            Invalid pixels are not managed here
+        Converts band to reflectance
 
         Args:
+            band_arr (xr.DataArray): Band array to convert
             path (Union[CloudPath, Path]): Band path
             band (BandNames): Band to read
-            resolution (Union[tuple, list, float]): Resolution of the wanted band, in dataset resolution unit (X, Y)
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
-            kwargs: Other arguments used to load bands
-        Returns:
-            XDS_TYPE: Band xarray
-
-        """
-        # Read band
-        band_xda = utils.read(
-            path,
-            resolution=resolution,
-            size=size,
-            resampling=Resampling.bilinear,
-            indexes=[self.band_names[band]],
-            **kwargs,
-        )
-
-        # Compute the correct radiometry of the band
-        original_dtype = band_xda.encoding.get("dtype", band_xda.dtype)
-        if original_dtype == "uint16":
-            band_xda /= 10000.0
-
-        # Convert type if needed
-        if band_xda.dtype != np.float32:
-            band_xda = band_xda.astype(np.float32)
-
-        return band_xda
-
-    def _manage_invalid_pixels(
-        self, band_arr: XDS_TYPE, band: obn, **kwargs
-    ) -> XDS_TYPE:
-        """
-        Manage invalid pixels (Nodata, saturated, defective...)
-        See
-        `here <https://earth.esa.int/eogateway/documents/20142/37627/Planet-combined-imagery-product-specs-2020.pdf>`_
-        (unusable data mask) for more information.
-
-        Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
-            kwargs: Other arguments used to load bands
+            **kwargs: Other keywords
 
         Returns:
-            XDS_TYPE: Cleaned band array
+            xr.DataArray: Band in reflectance
         """
-        # Nodata
-        no_data_mask = self._load_nodata(
-            size=(band_arr.rio.width, band_arr.rio.height)
-        ).values
+        # Get MTD XML file
+        root, nsmap = self.read_mtd()
 
-        # Dubious pixels mapping
-        dubious_bands = {
-            key: val + 1 for key, val in self.band_names.items() if val is not None
-        }
-        udm = self.open_mask("UNUSABLE", size=(band_arr.rio.width, band_arr.rio.height))
-        # Workaround:
-        # FutureWarning: The :code:`numpy.expand_dims` function is not implemented by Dask array.
-        # You may want to use the da.map_blocks function or something similar to silence this warning.
-        # Your code may stop working in a future release.
-        dubious_mask = rasters.read_bit_array(udm.values, dubious_bands[band])
+        # Open identifier
+        refl_coef = None
+        for band_mtd in root.iterfind(f".//{nsmap['ps']}bandSpecificMetadata"):
+            if (
+                int(band_mtd.findtext(f".//{nsmap['ps']}bandNumber"))
+                == self.bands[band].id
+            ):
+                refl_coef = float(
+                    band_mtd.findtext(f".//{nsmap['ps']}reflectanceCoefficient")
+                )
+                break
 
-        # Combine masks
-        mask = no_data_mask | dubious_mask
+        if refl_coef is None:
+            raise InvalidProductError(
+                "Couldn't find any reflectanceCoefficient in the product metadata!"
+            )
 
-        # -- Merge masks
-        return self._set_nodata_mask(band_arr, mask)
-
-    def _manage_nodata(self, band_arr: XDS_TYPE, band: obn, **kwargs) -> XDS_TYPE:
-        """
-        Manage only nodata pixels
-
-        Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
-            kwargs: Other arguments used to load bands
-
-        Returns:
-            XDS_TYPE: Cleaned band array
-        """
-        # Nodata
-        no_data_mask = self._load_nodata(
-            size=(band_arr.rio.width, band_arr.rio.height)
-        ).values
-
-        # -- Merge masks
-        return self._set_nodata_mask(band_arr, no_data_mask)
-
-    def _load_bands(
-        self,
-        bands: list,
-        resolution: float = None,
-        size: Union[list, tuple] = None,
-        **kwargs,
-    ) -> dict:
-        """
-        Load bands as numpy arrays with the same resolution (and same metadata).
-
-        Args:
-            bands list: List of the wanted bands
-            resolution (float): Band resolution in meters
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
-            kwargs: Other arguments used to load bands
-        Returns:
-            dict: Dictionary {band_name, band_xarray}
-        """
-        # Return empty if no band are specified
-        if not bands:
-            return {}
-
-        # Get band paths
-        band_paths = self.get_band_paths(bands, **kwargs)
-
-        # Open bands and get array (resampled if needed)
-        band_arrays = self._open_bands(
-            band_paths, resolution=resolution, size=size, **kwargs
-        )
-
-        return band_arrays
-
-    def _get_condensed_name(self) -> str:
-        """
-        Get PlanetScope products condensed name ({date}_PLA_{product_type}).
-
-        Returns:
-            str: Condensed name
-        """
-        return f"{self.get_datetime()}_{self.platform.name}_{self.product_type.name}"
+        # To reflectance
+        return band_arr * refl_coef
 
     @cache
     def get_mean_sun_angles(self) -> (float, float):
@@ -595,6 +571,36 @@ class PlaProduct(OpticalProduct):
 
         return azimuth_angle, zenith_angle
 
+    @cache
+    def get_mean_viewing_angles(self) -> (float, float, float):
+        """
+        Get Mean Viewing angles (azimuth, off-nadir and incidence angles)
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_mean_viewing_angles()
+
+        Returns:
+            (float, float, float): Mean azimuth, off-nadir and incidence angles
+        """
+        # Get MTD XML file
+        root, nsmap = self.read_mtd()
+
+        # Open zenith and azimuth angle
+        try:
+            az = float(root.findtext(f".//{nsmap['ps']}azimuthAngle"))
+            off_nadir = float(root.findtext(f".//{nsmap['ps']}spaceCraftViewAngle"))
+            incidence_angle = float(root.findtext(f".//{nsmap['eop']}incidenceAngle"))
+        except TypeError:
+            raise InvalidProductError(
+                "azimuthAngle, spaceCraftViewAngle or incidenceAngle not found in metadata!"
+            )
+
+        return az, off_nadir, incidence_angle
+
     @cache
     def _read_mtd(self) -> (etree._Element, dict):
         """
@@ -623,224 +629,71 @@ class PlaProduct(OpticalProduct):
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
 
-    def _has_cloud_band(self, band: BandNames) -> bool:
+    @cache
+    def get_cloud_cover(self) -> float:
         """
-        Does this products has the specified cloud band ?
-        """
-        # NOTE: CIRRUS == HEAVY HAZE
-
-        # FROM DOCUMENTATION: https://developers.planet.com/docs/data/udm-2/
-        # Percent of heavy haze values in dataset.
-        # Heavy haze values represent scene content areas (non-blackfilled) that contain thin low altitude clouds,
-        # higher altitude cirrus clouds, soot and dust which allow fair recognition of land cover features,
-        # but not having reliable interpretation of the radiometry or surface reflectance.
-        return True
-
-    def _open_clouds(
-        self,
-        bands: list,
-        resolution: float = None,
-        size: Union[list, tuple] = None,
-        **kwargs,
-    ) -> dict:
-        """
-        Load cloud files as xarrays.
-
-        CIRRUS is HEAVY_HAZE
-
-        Args:
-            bands (list): List of the wanted bands
-            resolution (int): Band resolution in meters
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
-            kwargs: Additional arguments
-        Returns:
-            dict: Dictionary {band_name, band_xarray}
-        """
-        band_dict = {}
-
-        # Load default xarray as a template
-        def_xarr = self._read_band(
-            self.get_default_band_path(),
-            band=self.get_default_band(),
-            resolution=resolution,
-            size=size,
-        )
-
-        # Load nodata
-        nodata = self._load_nodata(resolution, size).data
-
-        if bands:
-            for band in bands:
-                if band == ALL_CLOUDS:
-                    cloud = self._create_mask(
-                        def_xarr.rename(ALL_CLOUDS.name),
-                        (
-                            self.open_mask("CLOUD", resolution, size).data
-                            & self.open_mask("SHADOW", resolution, size).data
-                            & self.open_mask("HEAVY_HAZE", resolution, size).data
-                        ),
-                        nodata,
-                    )
-                elif band == SHADOWS:
-                    cloud = self._create_mask(
-                        def_xarr.rename(SHADOWS.name),
-                        self.open_mask("SHADOW", resolution, size).data,
-                        nodata,
-                    )
-                elif band == CLOUDS:
-                    cloud = self._create_mask(
-                        def_xarr.rename(CLOUDS.name),
-                        self.open_mask("CLOUD", resolution, size).data,
-                        nodata,
-                    )
-                elif band == CIRRUS:
-                    cloud = self._create_mask(
-                        def_xarr.rename(CIRRUS.name),
-                        self.open_mask("HEAVY_HAZE", resolution, size).data,
-                        nodata,
-                    )
-                elif band == RAW_CLOUDS:
-                    cloud = utils.read(self._get_path("udm2", "tif"), resolution, size)
-                else:
-                    raise InvalidTypeError(
-                        f"Non existing cloud band for Planet: {band}"
-                    )
-
-                # Rename
-                band_name = to_str(band)[0]
-
-                # Multi bands -> do not change long name
-                if band != RAW_CLOUDS:
-                    cloud.attrs["long_name"] = band_name
-                band_dict[band] = cloud.rename(band_name).astype(np.float32)
-
-        return band_dict
-
-    def open_mask(
-        self,
-        mask_id: str,
-        resolution: float = None,
-        size: Union[list, tuple] = None,
-    ) -> Union[xarray.DataArray, None]:
-        """
-        Open a Planet UDM2 (Usable Data Mask) mask, band by band, as a xarray.
-        Returns None if the mask is not available.
-
-        Do not open cloud mask with this function. Use :code:`load` instead.
-
-        See `here <https://developers.planet.com/docs/data/udm-2/>`_ for more
-        information.
-
-        Accepted mask IDs:
-
-        - :code:`CLEAR`:      Band 1     Clear map        [0, 1]  0: not clear, 1: clear
-        - :code:`SNOW`:       Band 2     Snow map         [0, 1]  0: no snow or ice, 1: snow or ice
-        - :code:`SHADOW`:     Band 3     Shadow map       [0, 1]  0: no shadow, 1: shadow
-        - :code:`LIGHT_HAZE`: Band 4     Light haze map   [0, 1]  0: no light haze, 1: light haze
-        - :code:`HEAVY_HAZE`: Band 5     Heavy haze map   [0, 1]  0: no heavy haze, 1: heavy haze
-        - :code:`CLOUD`:      Band 6     Cloud map        [0, 1]  0: no cloud, 1: cloud
-        - :code:`CONFIDENCE`: Band 7     Confidence map   [0-100] %age value: per-pixel algorithmic confidence in classif
-        - :code:`UNUSABLE`:   Band 8     Unusable pixels  --      Equivalent to the UDM asset
+        Get cloud cover as given in the metadata
 
         .. code-block:: python
 
-            >>> from eoreader.bands import *
             >>> from eoreader.reader import Reader
-            >>> path = r"SENTINEL2B_20190401-105726-885_L2A_T31UEQ_D_V2-0.zip"
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
-            >>> prod.open_mask("EDG", GREEN)
-            array([[[0, ..., 0]]], dtype=uint8)
-
-        Args:
-            mask_id: Mask ID
-            resolution (float): Band resolution in meters
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
+            >>> prod.get_cloud_cover()
+            55.5
 
         Returns:
-            Union[xarray.DataArray, None]: Mask array
-
+            float: Cloud cover as given in the metadata
         """
-        band_mapping = {
-            "CLEAR": 1,
-            "SNOW": 2,
-            "SHADOW": 3,
-            "LIGHT_HAZE": 4,
-            "HEAVY_HAZE": 5,
-            "CLOUD": 6,
-            "CONFIDENCE": 7,
-            "UNUSABLE": 8,
-        }
+        # Get MTD XML file
+        root, nsmap = self.read_mtd()
 
-        assert mask_id in band_mapping
-        mask_path = self._get_path("udm2", "tif")
-
-        # Open mask band
-        mask = utils.read(
-            mask_path,
-            resolution=resolution,
-            size=size,
-            resampling=Resampling.nearest,  # Nearest to keep the flags
-            masked=False,
-            indexes=[band_mapping[mask_id]],
-        )
-
-        return mask.astype(np.uint8)
-
-    def _load_nodata(
-        self,
-        resolution: float = None,
-        size: Union[list, tuple] = None,
-    ) -> Union[xarray.DataArray, None]:
-        """
-        Load nodata (unimaged pixels) as a numpy array.
-
-        See
-        `here <https://earth.esa.int/eogateway/documents/20142/37627/Planet-combined-imagery-product-specs-2020.pdf>`_
-        (unusable data mask) for more information.
-
-        Args:
-            resolution (float): Band resolution in meters
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
-
-        Returns:
-            Union[xarray.DataArray, None]: Nodata array
-
-        """
-        udm = self.open_mask("UNUSABLE", resolution, size)
-        nodata = udm.copy(data=rasters.read_bit_array(udm.compute(), 0))
-        return nodata.rename("NODATA")
-
-    def _get_path(self, filename: str, extension: str, invalid_lookahead=None) -> str:
-        """
-        Get either the archived path of the normal path of an asset
-
-        Args:
-            filename (str): Filename with wildcards
-            extension (str): Extension
-
-        Returns:
-            str: Path
-
-        """
-        path = ""
+        # Get the cloud cover
         try:
-            if self.is_archived:
-                if invalid_lookahead:
-                    regex = rf".*{filename}(?!{invalid_lookahead})\w*[_]*\.{extension}"
-                else:
-                    regex = rf".*{filename}\w*[_]*\.{extension}"
+            cc = float(root.findtext(f".//{nsmap['opt']}cloudCoverPercentage"))
 
-                path = files.get_archived_rio_path(self.path, regex)
-            else:
-                paths = list(self.path.glob(f"**/*{filename}*.{extension}"))
-                if invalid_lookahead:
-                    paths = [
-                        path for path in paths if invalid_lookahead not in str(path)
-                    ]
-                path = paths[0]
-        except (FileNotFoundError, IndexError):
-            LOGGER.warning(
-                f"No file corresponding to *{filename}*.{extension} found in {self.path}"
+        except TypeError:
+            raise InvalidProductError("opt:cloudCoverPercentage not found in metadata!")
+
+        return cc
+
+    @cache
+    def get_orbit_direction(self) -> OrbitDirection:
+        """
+        Get cloud cover as given in the metadata
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_orbit_direction().value
+            "DESCENDING"
+
+        Returns:
+            OrbitDirection: Orbit direction (ASCENDING/DESCENDING)
+        """
+        # Get MTD XML file
+        root, nsmap = self.read_mtd()
+
+        # Get the orbit direction
+        try:
+            od = OrbitDirection.from_value(
+                root.findtext(f".//{nsmap['eop']}orbitDirection")
             )
 
-        return path
+        except TypeError:
+            raise InvalidProductError("eop:orbitDirection not found in metadata!")
+
+        return od
+
+    def _get_condensed_name(self) -> str:
+        """
+        Get Planet products condensed name ({date}_{constellation}_{product_type}).
+
+        Returns:
+            str: Condensed name
+        """
+        return (
+            f"{self.get_datetime()}_{self.constellation.name}_{self.product_type.name}"
+        )
