@@ -32,15 +32,23 @@ from cloudpathlib import CloudPath
 from lxml import etree
 from rasterio.enums import Resampling
 from sertit import files, rasters, rasters_rio, vectors
-from sertit.rasters import XDS_TYPE
 
-from eoreader import cache, cached_property, utils
-from eoreader.bands import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS, BandNames
-from eoreader.bands import OpticalBandNames as obn
+from eoreader import cache, utils
+from eoreader.bands import (
+    ALL_CLOUDS,
+    CIRRUS,
+    CLOUDS,
+    RAW_CLOUDS,
+    SHADOWS,
+    BandNames,
+    SpectralBand,
+)
+from eoreader.bands import spectral_bands as spb
 from eoreader.bands import to_str
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.products import OpticalProduct, S2ProductType
-from eoreader.utils import DATETIME_FMT, EOREADER_NAME
+from eoreader.stac import CENTER_WV, FWHM, GSD, ID, NAME
+from eoreader.utils import DATETIME_FMT, EOREADER_NAME, simplify
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
@@ -52,17 +60,19 @@ class S2TheiaProduct(OpticalProduct):
     for more information.
     """
 
-    def _pre_init(self) -> None:
+    def _pre_init(self, **kwargs) -> None:
         """
         Function used to pre_init the products
         (setting needs_extraction and so on)
         """
+        self._has_cloud_cover = True
         self.needs_extraction = False
+        self._use_filename = True
 
         # Post init done by the super class
-        super()._pre_init()
+        super()._pre_init(**kwargs)
 
-    def _post_init(self) -> None:
+    def _post_init(self, **kwargs) -> None:
         """
         Function used to post_init the products
         (setting sensor type, band names and so on)
@@ -70,11 +80,11 @@ class S2TheiaProduct(OpticalProduct):
         self.tile_name = self._get_tile_name()
 
         # Post init done by the super class
-        super()._post_init()
+        super()._post_init(**kwargs)
 
-    def _set_resolution(self) -> float:
+    def _get_resolution(self) -> float:
         """
-        Set product default resolution (in meters)
+        Get product default resolution (in meters)
         """
         # S2: use 10m resolution, even if we have 60m and 20m resolution
         # In the future maybe set one resolution per band ?
@@ -100,26 +110,69 @@ class S2TheiaProduct(OpticalProduct):
     def _set_product_type(self) -> None:
         """Set products type"""
         self.product_type = S2ProductType.L2A
-        self.band_names.map_bands(
-            {
-                obn.BLUE: "2",
-                obn.GREEN: "3",
-                obn.RED: "4",
-                obn.VRE_1: "5",
-                obn.VRE_2: "6",
-                obn.VRE_3: "7",
-                obn.NIR: "8",
-                obn.NARROW_NIR: "8A",
-                obn.SWIR_1: "11",
-                obn.SWIR_2: "12",
-            }
-        )
+
+    def _set_instrument(self) -> None:
+        """
+        Set instrument
+
+        Sentinel-2: https://sentinels.copernicus.eu/web/sentinel/missions/sentinel-2/instrument-payload/
+        """
+        self.instrument = "MSI"
+
+    def _map_bands(self) -> None:
+        """
+        Map bands
+        """
+        l2a_bands = {
+            spb.BLUE: SpectralBand(
+                eoreader_name=spb.BLUE,
+                **{NAME: "B2", ID: "2", GSD: 10, CENTER_WV: 492, FWHM: 66},
+            ),
+            spb.GREEN: SpectralBand(
+                eoreader_name=spb.GREEN,
+                **{NAME: "B3", ID: "3", GSD: 10, CENTER_WV: 560, FWHM: 36},
+            ),
+            spb.RED: SpectralBand(
+                eoreader_name=spb.RED,
+                **{NAME: "B4", ID: "4", GSD: 10, CENTER_WV: 665, FWHM: 31},
+            ),
+            spb.VRE_1: SpectralBand(
+                eoreader_name=spb.VRE_1,
+                **{NAME: "B5", ID: "5", GSD: 20, CENTER_WV: 704, FWHM: 15},
+            ),
+            spb.VRE_2: SpectralBand(
+                eoreader_name=spb.VRE_2,
+                **{NAME: "B6", ID: "6", GSD: 20, CENTER_WV: 740, FWHM: 15},
+            ),
+            spb.VRE_3: SpectralBand(
+                eoreader_name=spb.VRE_3,
+                **{NAME: "B7", ID: "7", GSD: 20, CENTER_WV: 781, FWHM: 20},
+            ),
+            spb.NIR: SpectralBand(
+                eoreader_name=spb.NIR,
+                **{NAME: "B8A", ID: "8A", GSD: 10, CENTER_WV: 833, FWHM: 106},
+            ),
+            spb.NARROW_NIR: SpectralBand(
+                eoreader_name=spb.NARROW_NIR,
+                **{NAME: "B8", ID: "8", GSD: 20, CENTER_WV: 864, FWHM: 21},
+            ),
+            spb.SWIR_1: SpectralBand(
+                eoreader_name=spb.SWIR_1,
+                **{NAME: "B11", ID: "11", GSD: 20, CENTER_WV: 1612, FWHM: 92},
+            ),
+            spb.SWIR_2: SpectralBand(
+                eoreader_name=spb.SWIR_2,
+                **{NAME: "B12", ID: "12", GSD: 20, CENTER_WV: 2190, FWHM: 180},
+            ),
+        }
+        self.bands.map_bands(l2a_bands)
 
         # TODO: bands 1 and 9 are in ATB_R1 (10m) and ATB_R2 (20m)
         # B1 to be divided by 20
         # B9 to be divided by 200
 
-    @cached_property
+    @cache
+    @simplify
     def footprint(self) -> gpd.GeoDataFrame:
         """
         Get real footprint in UTM of the products (without nodata, in french == emprise utile)
@@ -133,7 +186,7 @@ class S2TheiaProduct(OpticalProduct):
             >>> from eoreader.reader import Reader
             >>> path = r"LC08_L1GT_023030_20200518_20200527_01_T2"
             >>> prod = Reader().open(path)
-            >>> prod.footprint
+            >>> prod.footprint()
                index                                           geometry
             0      0  POLYGON ((366165.000 4899735.000, 366165.000 4...
 
@@ -199,7 +252,7 @@ class S2TheiaProduct(OpticalProduct):
 
         return date
 
-    def _get_name(self) -> str:
+    def _get_name_constellation_specific(self) -> str:
         """
         Set product real name from metadata
 
@@ -222,6 +275,9 @@ class S2TheiaProduct(OpticalProduct):
         """
         Return the paths of required bands.
 
+        For Theia products, FRE bands are given because, it is written in the <documentation `https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/`>_
+        that "After having compiled the user feedback, it is likely that we will only distribute « FRE » files to reduce the data volume."
+
         .. code-block:: python
 
             >>> from eoreader.reader import Reader
@@ -230,8 +286,8 @@ class S2TheiaProduct(OpticalProduct):
             >>> prod = Reader().open(path)
             >>> prod.get_band_paths([GREEN, RED])
             {
-                <OpticalBandNames.GREEN: 'GREEN'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2/SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B3.tif',
-                <OpticalBandNames.RED: 'RED'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2/SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B4.tif'
+                <SpectralBandNames.GREEN: 'GREEN'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2/SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B3.tif',
+                <SpectralBandNames.RED: 'RED'>: 'SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2/SENTINEL2A_20190625-105728-756_L2A_T31UEQ_C_V2-2_FRE_B4.tif'
             }
 
         Args:
@@ -250,18 +306,19 @@ class S2TheiaProduct(OpticalProduct):
             if clean_band.is_file():
                 band_paths[band] = clean_band
             else:
+                band_id = self.bands[band].id
                 try:
                     if self.is_archived:
                         band_paths[band] = files.get_archived_rio_path(
-                            self.path, rf".*FRE_B{self.band_names[band]}\.tif"
+                            self.path, rf".*FRE_B{band_id}\.tif"
                         )
                     else:
                         band_paths[band] = files.get_file_in_dir(
-                            self.path, f"FRE_B{self.band_names[band]}.tif"
+                            self.path, f"FRE_B{band_id}.tif"
                         )
                 except (FileNotFoundError, IndexError) as ex:
                     raise InvalidProductError(
-                        f"Non existing {band} ({self.band_names[band]}) band for {self.path}"
+                        f"Non existing {band.name} ({band_id}) band for {self.path}"
                     ) from ex
 
         return band_paths
@@ -273,7 +330,7 @@ class S2TheiaProduct(OpticalProduct):
         resolution: Union[tuple, list, float] = None,
         size: Union[list, tuple] = None,
         **kwargs,
-    ) -> XDS_TYPE:
+    ) -> xr.DataArray:
         """
         Read band from disk.
 
@@ -287,11 +344,9 @@ class S2TheiaProduct(OpticalProduct):
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
             kwargs: Other arguments used to load bands
         Returns:
-            XDS_TYPE: Band xarray
-
+            xr.DataArray: Band xarray
         """
-        # Read band
-        band_xda = utils.read(
+        band_arr = utils.read(
             path,
             resolution=resolution,
             size=size,
@@ -299,32 +354,57 @@ class S2TheiaProduct(OpticalProduct):
             **kwargs,
         )
 
+        # Convert type if needed
+        if band_arr.dtype != np.float32:
+            band_arr = band_arr.astype(np.float32)
+
+        return band_arr
+
+    def _to_reflectance(
+        self,
+        band_arr: xr.DataArray,
+        path: Union[Path, CloudPath],
+        band: BandNames,
+        **kwargs,
+    ) -> xr.DataArray:
+        """
+        Converts band to reflectance
+
+        Args:
+            band_arr (xr.DataArray): Band array to convert
+            path (Union[CloudPath, Path]): Band path
+            band (BandNames): Band to read
+            **kwargs: Other keywords
+
+        Returns:
+            xr.DataArray: Band in reflectance
+        """
         # Compute the correct radiometry of the band (Theia product are stored into int16 bits)
-        original_dtype = band_xda.encoding.get("dtype", band_xda.dtype)
+        original_dtype = band_arr.encoding.get("dtype", band_arr.dtype)
         if original_dtype == "int16":
-            band_xda /= 10000.0
+            band_arr /= 10000.0
 
         # Convert type if needed
-        if band_xda.dtype != np.float32:
-            band_xda = band_xda.astype(np.float32)
+        if band_arr.dtype != np.float32:
+            band_arr = band_arr.astype(np.float32)
 
-        return band_xda
+        return band_arr
 
     def _manage_invalid_pixels(
-        self, band_arr: XDS_TYPE, band: obn, **kwargs
-    ) -> XDS_TYPE:
+        self, band_arr: xr.DataArray, band: BandNames, **kwargs
+    ) -> xr.DataArray:
         """
         Manage invalid pixels (Nodata, saturated, defective...)
         See `here <https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/>`_ for more
         information.
 
         Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
+            band_arr (xr.DataArray): Band array
+            band (BandNames): Band name as an SpectralBandNames
             kwargs: Other arguments used to load bands
 
         Returns:
-            XDS_TYPE: Cleaned band array
+            xr.DataArray: Cleaned band array
         """
         # -- Manage nodata from Theia band array
         # Theia nodata is already processed
@@ -358,17 +438,19 @@ class S2TheiaProduct(OpticalProduct):
         # -- Merge masks
         return self._set_nodata_mask(band_arr, mask)
 
-    def _manage_nodata(self, band_arr: XDS_TYPE, band: obn, **kwargs) -> XDS_TYPE:
+    def _manage_nodata(
+        self, band_arr: xr.DataArray, band: BandNames, **kwargs
+    ) -> xr.DataArray:
         """
         Manage only nodata pixels
 
         Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
+            band_arr (xr.DataArray): Band array
+            band (BandNames): Band name as a SpectralBandNames
             kwargs: Other arguments used to load bands
 
         Returns:
-            XDS_TYPE: Cleaned band array
+            xr.DataArray: Cleaned band array
         """
         # -- Manage nodata from Theia band array
         # Theia nodata is already processed
@@ -422,7 +504,7 @@ class S2TheiaProduct(OpticalProduct):
     def open_mask(
         self,
         mask_id: str,
-        band: Union[obn, str],
+        band: Union[BandNames, str],
         resolution: float = None,
         size: Union[list, tuple] = None,
     ) -> np.ndarray:
@@ -457,7 +539,7 @@ class S2TheiaProduct(OpticalProduct):
 
         Args:
             mask_id: Mask ID
-            band (Union[obn, str]): Band name as an OpticalBandNames or resolution ID: ['R1', 'R2']
+            band (Union[BandNames, str]): Band name as an SpectralBandNames or resolution ID: ['R1', 'R2']
             resolution (float): Band resolution in meters
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
 
@@ -467,14 +549,14 @@ class S2TheiaProduct(OpticalProduct):
         """
         # https://labo.obs-mip.fr/multitemp/sentinel-2/theias-sentinel-2-l2a-product-format/
         # For r_1, the band order is: B2, B3, B4, B8 and for r_2: B5, B6, B7, B8a, B11, B12
-        res_10m = [obn.BLUE, obn.GREEN, obn.RED, obn.NIR, "R1"]
+        res_10m = [spb.BLUE, spb.GREEN, spb.RED, spb.NIR, "R1"]
         res_20m = [
-            obn.VRE_1,
-            obn.VRE_2,
-            obn.VRE_3,
-            obn.NARROW_NIR,
-            obn.SWIR_1,
-            obn.SWIR_2,
+            spb.VRE_1,
+            spb.VRE_2,
+            spb.VRE_3,
+            spb.NARROW_NIR,
+            spb.SWIR_1,
+            spb.SWIR_2,
             "R2",
         ]
         if band in res_10m:
@@ -698,13 +780,13 @@ class S2TheiaProduct(OpticalProduct):
         return band_dict
 
     def _create_mask(
-        self, bit_array: XDS_TYPE, bit_ids: Union[int, list], nodata: np.ndarray
+        self, bit_array: xr.DataArray, bit_ids: Union[int, list], nodata: np.ndarray
     ) -> xr.DataArray:
         """
         Create a mask masked array (uint8) from a bit array, bit IDs and a nodata mask.
 
         Args:
-            bit_array (XDS_TYPE): Conditional array
+            bit_array (xr.DataArray): Conditional array
             bit_ids (Union[int, list]): Bit IDs
             nodata (np.ndarray): Nodata mask
 
@@ -718,3 +800,53 @@ class S2TheiaProduct(OpticalProduct):
         cond = reduce(lambda x, y: x | y, conds)  # Use every conditions (bitwise or)
 
         return super()._create_mask(bit_array, cond, nodata)
+
+    def get_quicklook_path(self) -> str:
+        """
+        Get quicklook path if existing (some providers are providing one quicklook, such as creodias)
+
+        Returns:
+            str: Quicklook path
+        """
+        quicklook_path = None
+        try:
+            if self.is_archived:
+                quicklook_path = files.get_archived_rio_path(
+                    self.path, file_regex=r".*QKL_ALL\.jpg"
+                )
+            else:
+                quicklook_path = str(next(self.path.glob("**/*QKL_ALL.jpg")))
+        except (StopIteration, FileNotFoundError):
+            LOGGER.warning(f"No quicklook found in {self.condensed_name}")
+
+        return quicklook_path
+
+    @cache
+    def get_cloud_cover(self) -> float:
+        """
+        Get cloud cover as given in the metadata
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_cloud_cover()
+            55.5
+
+        Returns:
+            float: Cloud cover as given in the metadata
+        """
+        # Get MTD XML file
+        root, nsmap = self.read_mtd()
+
+        # Get the cloud cover
+        try:
+            cc = float(root.findtext(".//QUALITY_INDEX[@name='CloudPercent']"))
+
+        except TypeError:
+            raise InvalidProductError(
+                "QUALITY_INDEXQUALITY_INDEX name='CloudPercent' not found in metadata!"
+            )
+
+        return cc
