@@ -107,12 +107,6 @@ class Constellation(ListEnum):
     SKY = "SkySat"
     """SkySat"""
 
-    CSK = "COSMO-SkyMed"
-    """COSMO-SkyMed"""
-
-    CSG = "COSMO-SkyMed 2nd Generation"
-    """COSMO-SkyMed 2nd Generation"""
-
     TSX = "TerraSAR-X"
     """TerraSAR-X"""
 
@@ -137,6 +131,12 @@ class Constellation(ListEnum):
     SPOT6 = "Spot-6"
     """SPOT-6"""
 
+    SPOT5 = "Spot-5"
+    """SPOT-5"""
+
+    SPOT4 = "Spot-4"
+    """SPOT-4"""
+
     VIS1 = "Vision-1"
     """Vision-1"""
 
@@ -170,6 +170,18 @@ class Constellation(ListEnum):
     SAOCOM = "SAOCOM-1"
     """SAOCOM-1"""
 
+    SV1 = "SuperView-1"
+    """SuperView-1"""
+
+    CSK = "COSMO-SkyMed"
+    """COSMO-SkyMed"""
+
+    CSG = "COSMO-SkyMed 2nd Generation"
+    """COSMO-SkyMed 2nd Generation"""
+
+    SPOT45 = "Spot-4/5"
+    """SPOT-4/5 (not a real constellation, but used as a template for SPOT4/5 products)"""
+
     CUSTOM = "CUSTOM"
     """Custom stack"""
 
@@ -209,6 +221,9 @@ CONSTELLATION_REGEX = {
     Constellation.PNEO: r"IMG_\d+_PNEO\d_(P|MS|PMS|MS-FS|PMS-FS)",
     Constellation.SPOT7: r"IMG_SPOT7_(P|MS|PMS|MS-N|MS-X|PMS-N|PMS-X)_\d{3}_\w",
     Constellation.SPOT6: r"IMG_SPOT6_(P|MS|PMS|MS-N|MS-X|PMS-N|PMS-X)_\d{3}_\w",
+    Constellation.SPOT45: r"SPVIEW_.+",
+    Constellation.SPOT4: r"SP04_HIR_(M_|I_|MI|X_|MX)___\d_\d{8}T\d{6}_\d{8}T\d{6}_.*",
+    Constellation.SPOT5: r"SP05_HRG_(HM_|J__|T__|X__|TX__|HMX)__\d_\d{8}T\d{6}_\d{8}T\d{6}_.*",
     Constellation.VIS1: r"VIS1_(PAN|BUN|PSH|MS4)_.+_\d{2}-\d",
     Constellation.RCM: r"RCM\d_OK\d+_PK\d+_\d_.{4,}_\d{8}_\d{6}(_(HH|VV|VH|HV|RV|RH)){1,4}_(SLC|GRC|GRD|GCC|GCD)",
     Constellation.QB: r"\d{12}_\d{2}_P\d{3}_(MUL|PAN|PSH|MOS)",
@@ -220,6 +235,10 @@ CONSTELLATION_REGEX = {
     Constellation.MAXAR: r"\d{12}_\d{2}_P\d{3}_(MUL|PAN|PSH|MOS)",
     Constellation.ICEYE: r"((SM|SL|SC|SLEA)[HW]*_\d{5,}|ICEYE_X\d_(SM|SL|SC|SLEA)H*_\d{5,}_\d{8}T\d{6})",
     Constellation.SAOCOM: r".+EOL1[ABCD]SARSAO1[AB]\d+(-product|)",
+    Constellation.SV1: [
+        r"\d{13}_\d{2}",
+        r"SV1-0[1-4]_\d{8}_L(1B|2A)\d{10}_\d{13}_\d{2}-(MUX|PSH)\.xml",
+    ],
 }
 
 MTD_REGEX = {
@@ -278,6 +297,28 @@ MTD_REGEX = {
     Constellation.MAXAR: r"\d{2}\w{3}\d{8}-.{4}(_R\dC\d|)-\d{12}_\d{2}_P\d{3}.TIL",
     Constellation.ICEYE: r"ICEYE_(X\d{1,}_|)(SLC|GRD)_((SM|SL|SC)H*|SLEA)_\d{5,}_\d{8}T\d{6}\.xml",
     Constellation.SAOCOM: r"S1[AB]_OPER_SAR_EOSSP__CORE_L1[A-D]_OL(F|VF)_\d{8}T\d{6}.xemt",
+    Constellation.SV1: r"SV1-0[1-4]_\d{8}_L(1B|2A)\d{10}_\d{13}_\d{2}-(MUX|PSH)\.xml",
+    Constellation.SPOT45: {
+        "nested": -1,  # File that can be found at any level (product/**/file)
+        "regex": [
+            r"METADATA\.DIM",  # Too generic name, check also a band
+            r"IMAGERY\.TIF",
+        ],
+    },
+    Constellation.SPOT4: {
+        "nested": -1,  # File that can be found at any level (product/**/file)
+        "regex": [
+            r"METADATA\.DIM",  # Too generic name, check also a band
+            r"IMAGERY\.TIF",
+        ],
+    },
+    Constellation.SPOT5: {
+        "nested": -1,  # File that can be found at any level (product/**/file)
+        "regex": [
+            r"METADATA\.DIM",  # Too generic name, check also a band
+            r"IMAGERY\.TIF",
+        ],
+    },
 }
 
 
@@ -344,7 +385,8 @@ class Reader:
         output_path: Union[str, CloudPath, Path] = None,
         method: CheckMethod = CheckMethod.MTD,
         remove_tmp: bool = False,
-        custom=False,
+        custom: bool = False,
+        constellation: Union[Constellation, str, list] = None,
         **kwargs,
     ) -> "Product":  # noqa: F821
         """
@@ -389,6 +431,7 @@ class Reader:
             method (CheckMethod): Checking method used to recognize the products
             remove_tmp (bool): Remove temp files (such as clean or orthorectified bands...) when the product is deleted
             custom (bool): True if we want to use a custom stack
+            constellation (Union[Constellation, str, list]): One or several constellations to help the Reader to choose more rapidly the correct Product
 
         Returns:
             Product: Correct products
@@ -406,30 +449,36 @@ class Reader:
                 archive_path=archive_path,
                 output_path=output_path,
                 remove_tmp=remove_tmp,
+                constellation=constellation,
                 **kwargs,
             )
         else:
             prod = None
-            for constellation in CONSTELLATION_REGEX.keys():
+            if constellation is None:
+                const_list = CONSTELLATION_REGEX.keys()
+            else:
+                const_list = Constellation.convert_from(constellation)
+
+            for const in const_list:
                 if method == CheckMethod.MTD:
-                    is_valid = self.valid_mtd(product_path, constellation)
+                    is_valid = self.valid_mtd(product_path, const)
                 elif method == CheckMethod.NAME:
-                    is_valid = self.valid_name(product_path, constellation)
+                    is_valid = self.valid_name(product_path, const)
                 else:
-                    is_valid = self.valid_name(
-                        product_path, constellation
-                    ) and self.valid_mtd(product_path, constellation)
+                    is_valid = self.valid_name(product_path, const) and self.valid_mtd(
+                        product_path, const
+                    )
 
                 if is_valid:
-                    sat_class = constellation.name.lower() + "_product"
+                    sat_class = const.name.lower() + "_product"
 
                     # Channel correctly the constellations to their generic files (just in case)
                     # TerraSAR-like constellations
-                    if constellation in [Constellation.TDX, constellation.PAZ]:
+                    if const in [Constellation.TDX, Constellation.PAZ]:
                         sat_class = "tsx_product"
-                        constellation = None  # All product names are the same, so assess it with MTD
+                        const = None  # All product names are the same, so assess it with MTD
                     # Maxar-like constellations
-                    elif constellation in [
+                    elif const in [
                         Constellation.QB,
                         Constellation.GE01,
                         Constellation.WV01,
@@ -438,9 +487,9 @@ class Reader:
                         Constellation.WV04,
                     ]:
                         sat_class = "maxar_product"
-                        constellation = None  # All product names are the same, so assess it with MTD
+                        const = None  # All product names are the same, so assess it with MTD
                     # Lansat constellations
-                    elif constellation in [
+                    elif const in [
                         Constellation.L1,
                         Constellation.L2,
                         Constellation.L3,
@@ -451,9 +500,12 @@ class Reader:
                         Constellation.L9,
                     ]:
                         sat_class = "landsat_product"
-                    # SPOT constellations
-                    elif constellation in [Constellation.SPOT6, Constellation.SPOT7]:
-                        sat_class = "spot_product"
+                    # SPOT-6/7 constellations
+                    elif const in [Constellation.SPOT6, Constellation.SPOT7]:
+                        sat_class = "spot67_product"
+                    # SPOT-4/5 constellations
+                    elif const in [Constellation.SPOT4, Constellation.SPOT5]:
+                        sat_class = "spot45_product"
 
                     # Manage both optical and SAR
                     try:
@@ -471,7 +523,7 @@ class Reader:
                         archive_path=archive_path,
                         output_path=output_path,
                         remove_tmp=remove_tmp,
-                        constellation=constellation,
+                        constellation=const,
                         **kwargs,
                     )
                     break
@@ -578,7 +630,7 @@ class Reader:
         nested = self._mtd_nested[constellation]
 
         # False by default
-        is_valid = [False for idx in regex_list]
+        is_valid = [False for _ in regex_list]
 
         # Folder
         if product_path.is_dir():
@@ -589,7 +641,7 @@ class Reader:
                     path for path in product_path.iterdir() if path.is_file()
                 )
             else:
-                nested_wildcard = "/".join(["*" for i in range(nested)])
+                nested_wildcard = "/".join(["*" for _ in range(nested)])
                 prod_files = list(product_path.glob(f"*{nested_wildcard}/*.*"))
 
         # Archive
