@@ -18,21 +18,27 @@
 import logging
 import os
 import platform
+import warnings
+from functools import wraps
 from pathlib import Path
-from typing import Union
+from typing import Callable, Union
 
+import geopandas as gpd
 import numpy as np
 import pandas as pd
 import xarray as xr
 from cloudpathlib import AnyPath, CloudPath
 from lxml import etree
+from rasterio import errors
 from rasterio.control import GroundControlPoint
 from rasterio.enums import Resampling
+from rasterio.errors import NotGeoreferencedWarning
 from rasterio.rpc import RPC
 from sertit import rasters
 
 from eoreader.env_vars import USE_DASK
-from eoreader.keywords import prune_keywords
+from eoreader.exceptions import InvalidProductError
+from eoreader.keywords import _prune_keywords
 
 EOREADER_NAME = "eoreader"
 DATETIME_FMT = "%Y%m%dT%H%M%S"
@@ -89,7 +95,7 @@ def get_data_dir() -> Union[CloudPath, Path]:
 
 def get_split_name(name: str) -> list:
     """
-    Get split name (with _). Removes empty index.
+    Get split name (with _). Removes empty indexes.
 
     Args:
         name (str): Name to split
@@ -148,7 +154,7 @@ def read(
         indexes (Union[int, list]): Indexes to load. Load the whole array if None.
         **kwargs: Optional keyword arguments to pass into rioxarray.open_rasterio().
     Returns:
-        Union[XDS_TYPE]: Masked xarray corresponding to the raster data and its meta data
+        xr.DataArray: Masked xarray corresponding to the raster data and its meta data
 
     """
     if use_dask():
@@ -156,16 +162,25 @@ def read(
     else:
         chunks = None
 
-    return rasters.read(
-        path,
-        resolution=resolution,
-        size=size,
-        resampling=resampling,
-        masked=masked,
-        indexes=indexes,
-        chunks=chunks,
-        **prune_keywords(**kwargs),
-    )
+    try:
+        # Disable georef warnings here as the SAR/Sentinel-3 products are not georeferenced
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", category=NotGeoreferencedWarning)
+            return rasters.read(
+                path,
+                resolution=resolution,
+                size=size,
+                resampling=resampling,
+                masked=masked,
+                indexes=indexes,
+                chunks=chunks,
+                **_prune_keywords(**kwargs),
+            )
+    except errors.RasterioIOError as ex:
+        if str(path).endswith("jp2") or str(path).endswith("tif"):
+            raise InvalidProductError(f"Corrupted file: {path}") from ex
+        else:
+            raise
 
 
 def write(xds: xr.DataArray, path: Union[str, CloudPath, Path], **kwargs) -> None:
@@ -207,7 +222,7 @@ def write(xds: xr.DataArray, path: Union[str, CloudPath, Path], **kwargs) -> Non
             pass
 
     # Write
-    rasters.write(xds, path=path, lock=lock, **prune_keywords(**kwargs))
+    rasters.write(xds, path=path, lock=lock, **_prune_keywords(**kwargs))
 
     # Set back the previous long name
     if previous_long_name and xds.rio.count > 1:
@@ -348,3 +363,61 @@ def open_rpc_file(path: Union[CloudPath, Path]) -> RPC:
         )
     except KeyError as msg:
         raise KeyError(f"Invalid RPC file, missing key: {msg}")
+
+
+def simplify_footprint(
+    footprint: gpd.GeoDataFrame, resolution: float, max_nof_vertices: int = 50
+) -> gpd.GeoDataFrame:
+    """
+    Simplify footprint
+
+    Args:
+        footprint (gpd.GeoDataFrame): Footprint to be simplified
+        resolution (float): Corresponding resolution
+        max_nof_vertices (int): Maximum number of vertices of the wanted footprint
+
+    Returns:
+        gpd.GeoDataFrame: Simplified footprint
+    """
+    # Number of pixels of tolerance
+    tolerance = [1, 2, 4, 8, 16, 32, 64]
+
+    # Process only if given footprint is too complex (too many vertices)
+    def simplify_geom(value):
+        nof_vertices = len(value.exterior.coords)
+        if nof_vertices > max_nof_vertices:
+            for tol in tolerance:
+                # Simplify footprint
+                value = value.simplify(
+                    tolerance=tol * resolution, preserve_topology=True
+                )
+
+                # Check if OK
+                nof_vertices = len(value.exterior.coords)
+                if nof_vertices < max_nof_vertices:
+                    break
+        return value
+
+    footprint.geometry = footprint.geometry.apply(simplify_geom)
+
+    return footprint
+
+
+def simplify(footprint_fct: Callable):
+    """
+    Simplify footprint decorator
+
+    Args:
+        function (Callable): Function to decorate
+
+    Returns:
+        Callable: decorated function
+    """
+
+    @wraps(footprint_fct)
+    def simplify_wrapper(self):
+        """ Simplify footprint wrapper """
+        footprint = footprint_fct(self)
+        return simplify_footprint(footprint, self.resolution)
+
+    return simplify_wrapper
